#/*-----------------------------------------------------------------*/
#/*! 
#  \file pycompute.py 
# \brief simple computation with a file and a date provided on the command line
#  e.g.: python pycompute  myfile.dat 2.451545E+06
#  or .e.g:  python pycompute  myfile.bsp myfile.tpc  2.451545E+06
#
#  \author  M. Gastineau 
#           Astronomie et Systemes Dynamiques, IMCCE, CNRS, Observatoire de Paris. 
#
#   Copyright, 2016, 2017, CNRS
#   email of the author : Mickael.Gastineau@obspm.fr
#
#  History:                                                                
#*/
#/*-----------------------------------------------------------------*/
#
# 
#/*-----------------------------------------------------------------*/
#/* License  of this file :
# This file is "triple-licensed", you have to choose one  of the three licenses 
# below to apply on this file.
# 
#    CeCILL-C
#    	The CeCILL-C license is close to the GNU LGPL.
#    	( http://www.cecill.info/licences/Licence_CeCILL-C_V1-en.html )
#   
# or CeCILL-B
#        The CeCILL-B license is close to the BSD.
#        (http://www.cecill.info/licences/Licence_CeCILL-B_V1-en.txt)
#  
# or CeCILL v2.1
#      The CeCILL license is compatible with the GNU GPL.
#      ( http://www.cecill.info/licences/Licence_CeCILL_V2.1-en.html )
# 
#
# This library is governed by the CeCILL-C, CeCILL-B or the CeCILL license under 
# French law and abiding by the rules of distribution of free software.  
# You can  use, modify and/ or redistribute the software under the terms 
# of the CeCILL-C,CeCILL-B or CeCILL license as circulated by CEA, CNRS and INRIA  
# at the following URL "http://www.cecill.info". 
# 
# As a counterpart to the access to the source code and  rights to copy,
# modify and redistribute granted by the license, users are provided only
# with a limited warranty  and the software's author,  the holder of the
# economic rights,  and the successive licensors  have only  limited
# liability. 
# 
# In this respect, the user's attention is drawn to the risks associated
# with loading,  using,  modifying and/or developing or reproducing the
# software by the user in light of its specific status of free software,
# that may mean  that it is complicated to manipulate,  and  that  also
# therefore means  that it is reserved for developers  and  experienced
# professionals having in-depth computer knowledge. Users are therefore
# encouraged to load and test the software's suitability as regards their
# requirements in conditions enabling the security of their systems and/or 
# data to be ensured and,  more generally, to use and operate it in the 
# same conditions as regards security. 
# 
# The fact that you are presently reading this means that you have had
# knowledge of the CeCILL-C,CeCILL-B or CeCILL license and that you accept its terms.
# */
# /*-----------------------------------------------------------------*/

from calcephpy import *
import sys

#/*-----------------------------------------------------------------*/
#/* print coordinates */
#/*-----------------------------------------------------------------*/
def printcoord(PV,name):
    print('{0} :\n{1}\n'.format(name,PV))

#/*-----------------------------------------------------------------*/
#/* main program */
#/*-----------------------------------------------------------------*/
if __name__ == '__main__':
    args = sys.argv
    if (len(sys.argv)<3):
        print("Usage : python pycompute.py filename1 filename2 ... filenamen juliandate")
        print("                  filename? : binary or spice ephemeris file names")
        print("                  juliandate : julian date (floating-point number)")
        print("")
        print("e.g.  : python pycompute.py inpop08a_m100_p100_littleendian.dat 2.451545E+06")
        print("e.g.  : python pycompute.py de421.bsp masses.tpc 2.451545E+06");
        sys.exit(1)
        
    jd0 = float(args[len(sys.argv)-1])

    # open the ephemeris file 
    print(args[1:len(sys.argv)-1])
    peph = CalcephBin.open(args[1:len(sys.argv)-1]) 

    #perform the computation
    PV = peph.compute_unit(jd0, 0E0, NaifId.EARTH, NaifId.SUN, 
                           Constants.UNIT_AU+Constants.UNIT_DAY+Constants.USE_NAIFID)
                           
    print("julian date : {0}".format(jd0))
    print("heliocentric coordinates of the Earth in km and km/s")
    print("cartesian heliocentric position of the Earth : {0}".format(PV[0:3]))
    print("cartesian heliocentric velocity of the Earth : {0}".format(PV[3:6]))

    # close the ephemeris file 
    peph.close()



# /*-----------------------------------------------------------------*/
# /*!
#  \file mcomputearrayfail.py
#  \brief Check the errors of the function calceph_compute with vectors.
#
#  \author  M. Gastineau
#           Astronomie et Systemes Dynamiques, IMCCE, CNRS, Observatoire de Paris.
#
#   Copyright, 2019, CNRS
#   email of the author : Mickael.Gastineau@obspm.fr
# */
# /*-----------------------------------------------------------------*/
#
# /*-----------------------------------------------------------------*/
# /* License  of this file :
# This file is "triple-licensed", you have to choose one  of the three licenses
# below to apply on this file.
#
#    CeCILL-C
#    	The CeCILL-C license is close to the GNU LGPL.
#    	( http://www.cecill.info/licences/Licence_CeCILL-C_V1-en.html )
#
# or CeCILL-B
#        The CeCILL-B license is close to the BSD.
#        (http://www.cecill.info/licences/Licence_CeCILL-B_V1-en.txt)
#
# or CeCILL v2.1
#      The CeCILL license is compatible with the GNU GPL.
#      ( http://www.cecill.info/licences/Licence_CeCILL_V2.1-en.html )
#
#
# This library is governed by the CeCILL-C, CeCILL-B or the CeCILL license under
# French law and abiding by the rules of distribution of free software.
# You can  use, modify and/ or redistribute the software under the terms
# of the CeCILL-C,CeCILL-B or CeCILL license as circulated by CEA, CNRS and INRIA
# at the following URL "http://www.cecill.info".
#
# As a counterpart to the access to the source code and  rights to copy,
# modify and redistribute granted by the license, users are provided only
# with a limited warranty  and the software's author,  the holder of the
# economic rights,  and the successive licensors  have only  limited
# liability.
#
# In this respect, the user's attention is drawn to the risks associated
# with loading,  using,  modifying and/or developing or reproducing the
# software by the user in light of its specific status of free software,
# that may mean  that it is complicated to manipulate,  and  that  also
# therefore means  that it is reserved for developers  and  experienced
# professionals having in-depth computer knowledge. Users are therefore
# encouraged to load and test the software's suitability as regards their
# requirements in conditions enabling the security of their systems and/or
# data to be ensured and,  more generally, to use and operate it in the
# same conditions as regards security.
#
# The fact that you are presently reading this means that you have had
# knowledge of the CeCILL-C,CeCILL-B or CeCILL license and that you accept its terms.
# */
# /*-----------------------------------------------------------------*/

# /*-----------------------------------------------------------------*/
# /* main program */
# /*-----------------------------------------------------------------*/
import unittest
import openfiles

from calcephpy import CalcephBin


class TestOpen(unittest.TestCase):

    # set different size of arrays
    def test_mcomputefail(self):
        peph = CalcephBin.open(openfiles.prefixsrc(
            "../../examples/example1.dat"))
        jd0 = [-9.0721875000000000E+03, -
               9.0721875000000000E+03, -9.0721875000000000E+03]
        dt = [0, 0]
        target = 1
        center = 12
        res = 1
        try:
            PV = peph.compute(jd0, dt, target, center)
            print("different size of vectors does not fail")
        except:
            print("normal error")
            res = 0

        if res == 1:
            raise RuntimeError("error not detected")


if __name__ == '__main__':
    unittest.main()



# /*-----------------------------------------------------------------*/
# /*!
#  \file timeconversion.py
#  \brief Check if calceph_time_... works.
#
#  \author  M. Gastineau
#           Astronomie et Systemes Dynamiques, IMCCE, CNRS, Observatoire de Paris.
#
#   Copyright, 2025-2026, CNRS
#   email of the author : Mickael.Gastineau@obspm.fr
# */
# /*-----------------------------------------------------------------*/
#
# /*-----------------------------------------------------------------*/
# /* License  of this file :
# This file is "triple-licensed", you have to choose one  of the three licenses
# below to apply on this file.
#
#    CeCILL-C
#    	The CeCILL-C license is close to the GNU LGPL.
#    	( http://www.cecill.info/licences/Licence_CeCILL-C_V1-en.html )
#
# or CeCILL-B
#        The CeCILL-B license is close to the BSD.
#        (http://www.cecill.info/licences/Licence_CeCILL-B_V1-en.txt)
#
# or CeCILL v2.1
#      The CeCILL license is compatible with the GNU GPL.
#      ( http://www.cecill.info/licences/Licence_CeCILL_V2.1-en.html )
#
#
# This library is governed by the CeCILL-C, CeCILL-B or the CeCILL license under
# French law and abiding by the rules of distribution of free software.
# You can  use, modify and/ or redistribute the software under the terms
# of the CeCILL-C,CeCILL-B or CeCILL license as circulated by CEA, CNRS and INRIA
# at the following URL "http://www.cecill.info".
#
# As a counterpart to the access to the source code and  rights to copy,
# modify and redistribute granted by the license, users are provided only
# with a limited warranty  and the software's author,  the holder of the
# economic rights,  and the successive licensors  have only  limited
# liability.
#
# In this respect, the user's attention is drawn to the risks associated
# with loading,  using,  modifying and/or developing or reproducing the
# software by the user in light of its specific status of free software,
# that may mean  that it is complicated to manipulate,  and  that  also
# therefore means  that it is reserved for developers  and  experienced
# professionals having in-depth computer knowledge. Users are therefore
# encouraged to load and test the software's suitability as regards their
# requirements in conditions enabling the security of their systems and/or
# data to be ensured and,  more generally, to use and operate it in the
# same conditions as regards security.
#
# The fact that you are presently reading this means that you have had
# knowledge of the CeCILL-C,CeCILL-B or CeCILL license and that you accept its terms.
# */
# /*-----------------------------------------------------------------*/

# /*-----------------------------------------------------------------*/
# /* main program */
# /*-----------------------------------------------------------------*/
import unittest
import openfiles
import math

from calcephpy import CalcephBin, Constants


# check the result for the calendar
def check_cal(computed_date, expected_date):
    ye, moe, de, he, mie, se = expected_date
    yc, moc, dc, hc, mic, sc = computed_date
    if (
        ye != yc
        or moe != moc
        or de != dc
        or hc != he
        or mie != mic
        or abs(se - sc) > 4e-5
    ):
        print("expected date: ", expected_date)
        print("computed date: ", computed_date)
        raise RuntimeError("invalid calendar date")


# check the result for the julianday
def check_jd(computed_date, expected_date):
    jd0e, jdfrace = expected_date
    jd0c, jdfracc = computed_date
    if abs((jd0c - jd0e) + (jdfracc - jdfrace)) > 1e-6:
        print("expected date: ", expected_date)
        print("computed date: ", computed_date)
        raise RuntimeError("invalid julian day")


class TestTime(unittest.TestCase):

    def test_time_jd_to_cal(self):
        peph = CalcephBin.open(openfiles.prefixsrc("../../tests/example_lsk.tls"))

        computed_date = peph.time_jd_to_cal(Constants.TAI, 2457948.0, 0.76207291667)
        check_cal(computed_date, [2017, 7, 14, 6, 17, 23.1])

        computed_date = peph.time_jd_to_cal(Constants.TCB, 2457436.0, 0.11835879629)
        check_cal(computed_date, [2016, 2, 17, 14, 50, 26.2])

        computed_date = peph.time_jd_to_cal(
            Constants.UTC, 2451545.0, 0.04554398148148146
        )
        check_cal(computed_date, [2000, 1, 1, 13, 5, 35.0])

        peph.close()

    def test_time_cal_to_jd(self):
        peph = CalcephBin.open(openfiles.prefixsrc("../../tests/example_lsk.tls"))

        computed_date = peph.time_cal_to_jd(Constants.TT, 2016, 2, 18, 14, 50, 26.2)
        check_jd(computed_date, [2457437.0, 0.11835879629])

        computed_date = peph.time_cal_to_jd(Constants.UTC, 2000, 1, 12, 13, 5, 35.0)
        check_jd(computed_date, [2451556.0, 0.04554398148148146])

        peph.close()

    def test_time_str_to_jd(self):
        peph = CalcephBin.open(openfiles.prefixsrc("../../tests/example_lsk.tls"))

        computed_date = peph.time_str_to_jd(
            Constants.TT, "2029 OCT 16 13:14:11.4967158436775208"
        )
        check_jd(computed_date, [2462426.0, 0.0515219527296722])

        computed_date = peph.time_str_to_jd(
            Constants.TIMESCALE_FROM_STR, "1996 January 1,  06:00:0.0  (UTC)"
        )
        check_jd(computed_date, [2450083, 0.75])

        peph.close()

    def test_time_jd_tt_to_jd_tdb(self):
        peph = CalcephBin.open(openfiles.prefixsrc("../../tests/example_lsk.tls"))

        peph.time_set_relationship_tt_tdb(1)

        computed_date = peph.time_jd_tt_to_jd_tdb(2452425, 0.989772840403)
        check_jd(computed_date, [2452425, 0.989772851113])

        computed_date = peph.time_jd_tdb_to_jd_tt(2452425, 0.989772851113)
        check_jd(computed_date, [2452425, 0.989772840403])

        peph.close()

    def test_time_jd_tcb_to_jd_tdb(self):
        peph = CalcephBin.open(openfiles.prefixsrc("../../tests/example_lsk.tls"))

        computed_date = peph.time_jd_tcb_to_jd_tdb(2450083.0, 0.1268436964601278)
        check_jd(computed_date, [2450083.0, 0.1267361110076308])

        computed_date = peph.time_jd_tdb_to_jd_tcb(2450083.0, 0.1267361110076308)
        check_jd(computed_date, [2450083.0, 0.1268436964601278])

        peph.close()

    def test_time_str_any_to_jd_tdb(self):
        peph = CalcephBin.open(openfiles.prefixsrc("../../tests/example_lsk.tls"))

        peph.time_set_relationship_tt_tdb(1)
        computed_date = peph.time_str_any_to_jd_tdb("1995 June 13  23:59:59.5  (UTC)")
        check_jd(computed_date, [2449882, 0.5007023680955172])

        peph.close()

    def test_time_str_utc_to_jd_tdb(self):
        peph = CalcephBin.open(openfiles.prefixsrc("../../tests/example_lsk.tls"))

        peph.time_set_relationship_tt_tdb(1)
        computed_date = peph.time_str_utc_to_jd_tdb("1988 June 13, 12:29:48 ")
        check_jd(computed_date, [2447326, 0.0213447287678719])

        peph.close()

    def tests_time_cal_utc_to_jd_tdb(self):
        peph = CalcephBin.open(openfiles.prefixsrc("../../tests/example_lsk.tls"))

        peph.time_set_relationship_tt_tdb(1)
        computed_date = peph.time_cal_utc_to_jd_tdb(1995, 12, 31, 23, 59, 59.5)
        check_jd(computed_date, [2450083, 0.5007023601792753])

        peph.close()

    def tests_time_jd_tdb_to_cal_utc(self):
        peph = CalcephBin.open(openfiles.prefixsrc("../../tests/example_lsk.tls"))

        peph.time_set_relationship_tt_tdb(1)
        computed_date = peph.time_jd_tdb_to_cal_utc(2450083, 0.5007023601792753)
        check_cal(computed_date, [1995, 12, 31, 23, 59, 59.5])

        computed_date = peph.time_jd_tdb_to_cal_utc(
            2450083, 0.5007023601792753 + 1.0 / 86401.0
        )
        check_cal(computed_date, [1995, 12, 31, 23, 59, 60.5])

        peph.close()

    def tests_time_str_spacecraft_clock_to_jd_tdb(self):
        peph = CalcephBin.open([openfiles.prefixsrc("../../tests/example_lsk.tls"), openfiles.prefixsrc("../../tests/example_sclk.tsc")])

        peph.time_set_relationship_tt_tdb(1)
        computed_date = peph.time_str_spacecraft_clock_to_jd_tdb(28, "1/0706865508:31865")
        check_jd(computed_date, [2459725, 0.81458599643883644603 ])

        computed_date = peph.time_jd_tdb_to_str_spacecraft_clock(
            28,  2459744,  0.35689482379893888719
        )
        expected_date = "1/0708467563:63527"
        if (computed_date!=expected_date):
            print("computed date", computed_date)
            print("expected date", expected_date)
            raise RuntimeError("time_jd_tdb_to_str_spacecraft_clock fails")
        
        peph.close()


if __name__ == "__main__":
    unittest.main()



#/*-----------------------------------------------------------------*/
#/*! 
#  \file pyerror.py 
# \brief Example of usage of the error handler functions with python 
#        This example generates errors.
#        In a first step, on error, it displays a custom message using 
#         its own subroutine.
#        In a second step, on error, the library displays the default error message 
#         but continues the execution.
#        In a last step, on error, the library displays the default error message 
#         but exits.
#        So the message "goodbye" is never displayed.
#
#  \author  M. Gastineau 
#           Astronomie et Systemes Dynamiques, IMCCE, CNRS, Observatoire de Paris. 
#
#   Copyright,  2016, 2017, CNRS
#   email of the author : Mickael.Gastineau@obspm.fr
#
#  History:                                                                
#*/
#/*-----------------------------------------------------------------*/
#
# 
#/*-----------------------------------------------------------------*/
#/* License  of this file :
# This file is "triple-licensed", you have to choose one  of the three licenses 
# below to apply on this file.
# 
#    CeCILL-C
#        The CeCILL-C license is close to the GNU LGPL.
#        ( http://www.cecill.info/licences/Licence_CeCILL-C_V1-en.html )
#   
# or CeCILL-B
#        The CeCILL-B license is close to the BSD.
#        (http://www.cecill.info/licences/Licence_CeCILL-B_V1-en.txt)
#  
# or CeCILL v2.1
#      The CeCILL license is compatible with the GNU GPL.
#      ( http://www.cecill.info/licences/Licence_CeCILL_V2.1-en.html )
# 
#
# This library is governed by the CeCILL-C, CeCILL-B or the CeCILL license under 
# French law and abiding by the rules of distribution of free software.  
# You can  use, modify and/ or redistribute the software under the terms 
# of the CeCILL-C,CeCILL-B or CeCILL license as circulated by CEA, CNRS and INRIA  
# at the following URL "http://www.cecill.info". 
# 
# As a counterpart to the access to the source code and  rights to copy,
# modify and redistribute granted by the license, users are provided only
# with a limited warranty  and the software's author,  the holder of the
# economic rights,  and the successive licensors  have only  limited
# liability. 
# 
# In this respect, the user's attention is drawn to the risks associated
# with loading,  using,  modifying and/or developing or reproducing the
# software by the user in light of its specific status of free software,
# that may mean  that it is complicated to manipulate,  and  that  also
# therefore means  that it is reserved for developers  and  experienced
# professionals having in-depth computer knowledge. Users are therefore
# encouraged to load and test the software's suitability as regards their
# requirements in conditions enabling the security of their systems and/or 
# data to be ensured and,  more generally, to use and operate it in the 
# same conditions as regards security. 
# 
# The fact that you are presently reading this means that you have had
# knowledge of the CeCILL-C,CeCILL-B or CeCILL license and that you accept its terms.
# */
# /*-----------------------------------------------------------------*/

from calcephpy import *

#/*-----------------------------------------------------------------*/
#/* custom error handler */
#/*-----------------------------------------------------------------*/
def myhandler(msg):
    print("The calceph calls the function myhandler");
    print("The message contains {0} characters\n".format(len(msg)))
    print("The error message is :")
    print("----------------------")
    print(msg)
    print("----------------------")
    print("The error handler returns")

#/*-----------------------------------------------------------------*/
#/* main program */
#/*-----------------------------------------------------------------*/
if __name__ == '__main__':
    jd0=-2442457E16
    dt=0.5E0
    # open the ephemeris file 
    peph = CalcephBin.open("example1.dat")
    print("Step 1 :")
    print("It displays a custom message using its own subroutine\n")
    # set the  error handler to use my own callback 
    seterrorhandler(3, myhandler)
    # call with an invalid time 
    PV = peph.compute(jd0, dt, 10, 3)
    
    print("\n\nStep 2 :")
    print("Calceph library displays the message but it raises an exception\n")
    # set the error handler to display error and continue 
    seterrorhandler(1, 0)
    try:
        # call with an invalid time 
        PV = peph.compute(jd0, dt, 10, 3)
    except:
        print("Python raises an error")
    
    print("\n\nStep 3 :")
    print("calceph library displays the message but the programs exits\n")
    #set the  error handler to stop on error */
    seterrorhandler(2, 0);
    # call with an invalid time
    PV = peph.compute(jd0, dt, 10, 3)
    
    print("Goodbye");
    print("If you see this message, you find a bug !");
    
    # close the ephemeris file 
    peph.close()



# /*-----------------------------------------------------------------*/
# /*!
#  \file pymultiple.py
#  \brief Example of usage of the multiple file access functions with the python interface.
#         This example reads the constant EMRAT, AU, GM_Mer and print their values.
#         It computes for a date
#          the geocentric moon coordinates,
#          the value TT-TDB
#          the heliocentric coordinates of Mars.
#
#  \author  M. Gastineau
#           Astronomie et Systemes Dynamiques, IMCCE, CNRS, Observatoire de Paris.
#
#   Copyright,  2016-2023, CNRS
#   email of the author : Mickael.Gastineau@obspm.fr
#
#  History:
# */
# /*-----------------------------------------------------------------*/
#
#
# /*-----------------------------------------------------------------*/
# /* License  of this file :
# This file is "triple-licensed", you have to choose one  of the three licenses
# below to apply on this file.
#
#    CeCILL-C
#    	The CeCILL-C license is close to the GNU LGPL.
#    	( http://www.cecill.info/licences/Licence_CeCILL-C_V1-en.html )
#
# or CeCILL-B
#        The CeCILL-B license is close to the BSD.
#        (http://www.cecill.info/licences/Licence_CeCILL-B_V1-en.txt)
#
# or CeCILL v2.1
#      The CeCILL license is compatible with the GNU GPL.
#      ( http://www.cecill.info/licences/Licence_CeCILL_V2.1-en.html )
#
#
# This library is governed by the CeCILL-C, CeCILL-B or the CeCILL license under
# French law and abiding by the rules of distribution of free software.
# You can  use, modify and/ or redistribute the software under the terms
# of the CeCILL-C,CeCILL-B or CeCILL license as circulated by CEA, CNRS and INRIA
# at the following URL "http://www.cecill.info".
#
# As a counterpart to the access to the source code and  rights to copy,
# modify and redistribute granted by the license, users are provided only
# with a limited warranty  and the software's author,  the holder of the
# economic rights,  and the successive licensors  have only  limited
# liability.
#
# In this respect, the user's attention is drawn to the risks associated
# with loading,  using,  modifying and/or developing or reproducing the
# software by the user in light of its specific status of free software,
# that may mean  that it is complicated to manipulate,  and  that  also
# therefore means  that it is reserved for developers  and  experienced
# professionals having in-depth computer knowledge. Users are therefore
# encouraged to load and test the software's suitability as regards their
# requirements in conditions enabling the security of their systems and/or
# data to be ensured and,  more generally, to use and operate it in the
# same conditions as regards security.
#
# The fact that you are presently reading this means that you have had
# knowledge of the CeCILL-C,CeCILL-B or CeCILL license and that you accept its terms.
# */
# /*-----------------------------------------------------------------*/

from calcephpy import *

# /*-----------------------------------------------------------------*/
# /* print coordinates */
# /*-----------------------------------------------------------------*/


def printcoord(PV, name):
    print('{0} :\n{1}\n'.format(name, PV))


# /*-----------------------------------------------------------------*/
# /* main program */
# /*-----------------------------------------------------------------*/
if __name__ == '__main__':
    jd0 = 2442457
    dt = 0.5E0
    # open the ephemeris file
    peph = CalcephBin.open("example1.dat")
    print("The ephemeris is already opened\n")

    # print the values of AU, EMRAT and GM_Mer
    AU = peph.getconstant("AU")
    print("AU={0}".format(AU))
    EMRAT = peph.getconstant("EMRAT")
    print("EMRAT={0}".format(EMRAT))
    GM_Mer = peph.getconstant("GM_Mer")
    print("GM_Mer={0}".format(GM_Mer))

    # compute and print the coordinates
    # the geocentric moon coordinates
    moon = peph.getidbyname("Moon", 0)
    earth = peph.getidbyname("Earth", 0)
    PV = peph.compute(jd0, dt, moon, earth)
    printcoord(PV, "geocentric coordinates of the Moon in AU and AU/day")
    PV = peph.compute_unit(jd0, dt, NaifId.MOON, NaifId.EARTH,
                           Constants.UNIT_KM+Constants.UNIT_SEC+Constants.USE_NAIFID)
    printcoord(PV, "geocentric coordinates of the Moon in km and km/s")

    # the value TT-TDB
    PV = peph.compute(jd0, dt, 16, 0)
    print("TT-TDB = {0}\n".format(PV[0]))

    # the heliocentric coordinates of Mars
    PV = peph.compute_unit(jd0, dt, NaifId.MARS_BARYCENTER, NaifId.SUN,
                           Constants.UNIT_AU+Constants.UNIT_DAY+Constants.USE_NAIFID)
    printcoord(PV, "heliocentric coordinates of Mars")

    # print the whole list of the constants
    print("list of constants")
    for j in range(1, peph.getconstantcount()+1):
        nameconstant, valueconstant = peph.getconstantindex(j)
        print("'{0}'\t= {1}".format(nameconstant, valueconstant))

    # close the ephemeris file
    peph.close()
    print("The ephemeris is already closed")



#/*-----------------------------------------------------------------*/
#/*! 
#  \file calcephpy.pxd 
#  \brief public Python API for calceph library
#        access and interpolate INPOP and JPL Ephemeris data.
#
#  \author  M. Gastineau 
#           Astronomie et Systemes Dynamiques, LTE, CNRS, Observatoire de Paris. 
#
#   Copyright, 2016-2026,  CNRS
#   email of the author : Mickael.Gastineau@obspm.fr
#*/
#/*-----------------------------------------------------------------*/
# 
#/*-----------------------------------------------------------------*/
#/* License  of this file :
# This file is "triple-licensed", you have to choose one  of the three licenses 
# below to apply on this file.
# 
#    CeCILL-C
#    	The CeCILL-C license is close to the GNU LGPL.
#    	( http://www.cecill.info/licences/Licence_CeCILL-C_V1-en.html )
#   
# or CeCILL-B
#        The CeCILL-B license is close to the BSD.
#        (http://www.cecill.info/licences/Licence_CeCILL-B_V1-en.txt)
#  
# or CeCILL v2.1
#      The CeCILL license is compatible with the GNU GPL.
#      ( http://www.cecill.info/licences/Licence_CeCILL_V2.1-en.html )
# 
#
# This library is governed by the CeCILL-C, CeCILL-B or the CeCILL license under 
# French law and abiding by the rules of distribution of free software.  
# You can  use, modify and/ or redistribute the software under the terms 
# of the CeCILL-C,CeCILL-B or CeCILL license as circulated by CEA, CNRS and INRIA  
# at the following URL "http://www.cecill.info". 
# 
# As a counterpart to the access to the source code and  rights to copy,
# modify and redistribute granted by the license, users are provided only
# with a limited warranty  and the software's author,  the holder of the
# economic rights,  and the successive licensors  have only  limited
# liability. 
# 
# In this respect, the user's attention is drawn to the risks associated
# with loading,  using,  modifying and/or developing or reproducing the
# software by the user in light of its specific status of free software,
# that may mean  that it is complicated to manipulate,  and  that  also
# therefore means  that it is reserved for developers  and  experienced
# professionals having in-depth computer knowledge. Users are therefore
# encouraged to load and test the software's suitability as regards their
# requirements in conditions enabling the security of their systems and/or 
# data to be ensured and,  more generally, to use and operate it in the 
# same conditions as regards security. 
# 
# The fact that you are presently reading this means that you have had
# knowledge of the CeCILL-C,CeCILL-B or CeCILL license and that you accept its terms.
# */
# /*-----------------------------------------------------------------*/


cdef extern from "calceph.h":
    
    #/*-----------------------------------------------------------------*/
    #/* error handler */
    #/*-----------------------------------------------------------------*/
    #/*! set the error handler */
    void calceph_seterrorhandler(int typehandler, void (*userfunc)(const char*));

    #/*-----------------------------------------------------------------*/
    #/* multiple access API per thread/process */
    #/*-----------------------------------------------------------------*/
    #/*! ephemeris descriptor */
    ctypedef struct t_calcephbin:
        pass
    
    #/*! open an ephemeris data file */
    t_calcephbin* calceph_open(const char *filename)
    
    #/*! open a list of ephemeris data file */
    t_calcephbin* calceph_open_array(int n, const char  ** filename)
    
    #/*! prefetch all data to memory */
    int calceph_prefetch(t_calcephbin* eph)
    
    #/*! compute the position <x,y,z> and velocity <xdot,ydot,zdot>
    #    for a given target and center at a single time. The output is in UA, UA/day, radians */
    int calceph_compute(t_calcephbin* eph, double JD0, double time, int target, 
                                           int center, double PV[6])
    
    #/*! compute the position <x,y,z> and velocity <xdot,ydot,zdot>
    #    for a given target and center at a single time. The output is expressed according to unit */
    int calceph_compute_unit(t_calcephbin* eph, double JD0, double time, int target, 
                                           int center, int unit, double PV[6])
    
    #/*! compute the orientation <euler angles> and their derivatives for a given target  at a single time. 
    #    The output is expressed according to unit */
    int calceph_orient_unit(t_calcephbin* eph, double JD0, double time, int target, 
                                               int unit, double PV[6])
                                               
    #/*! compute the rotational angular momentum G/(mR^2) and their derivatives for a given target  at a single time.
    #    The output is expressed according to unit */
    int calceph_rotangmom_unit(t_calcephbin* eph, double JD0, double time, int target,
                                              int unit, double PV[6])

    #/*! According to the value of order, compute the position <x,y,z> 
    #    and their first, second and third derivatives (velocity, acceleration, jerk)
    #    for a given target and center at a single time. The output is expressed according to unit */
    int calceph_compute_order(t_calcephbin* eph, double JD0, double time, int target,
                                                    int center, int unit, int order, double *PVAJ)
        
    #/*! According to the value of order,  compute the orientation <euler angles> 
    #    and their first, second and third derivatives for a given target  at a single time.
    #     The output is expressed according to unit */
    int calceph_orient_order(t_calcephbin* eph, double JD0, double time, int target,
                                                int unit, int order, double *PVAJ)
    
    #/*! According to the value of order,  compute the rotational angular momentum G/(mR^2) 
    #     and their first, second and third derivatives for a given target at a single time.
    # The output is expressed according to unit */
    int calceph_rotangmom_order(t_calcephbin* eph, double JD0, double time, int target,
                                              int unit, int order, double *PVAJ)

    #/*! compute the position <x,y,z> and velocity <xdot,ydot,zdot>
    # for a given target and center for n times. The output is in UA, UA/day,
    # radians */
    int calceph_vector_compute(t_calcephbin* eph, int n, const double* JD0,
                                                const double* time, int target, int center,
                                                int storage, double* PV);

    #/*! get first value from the specified name in the ephemeris file */
    int calceph_getconstantsd(t_calcephbin* eph, const char* name, double *value)
    
    #/*! get nvalue values from the specified name in the ephemeris file */
    int calceph_getconstantvd(t_calcephbin* eph, const char* name, double *arrayvalue, int nvalue)
    
    #/*! get first value from the specified name in the ephemeris file */
    int calceph_getconstantss(t_calcephbin* eph, const char* name, char value[1024])
    
    #/*! get nvalue values from the specified name in the ephemeris file */
    int calceph_getconstantvs(t_calcephbin* eph, const char* name, char (*arrayvalue)[1024], int nvalue)

    #/*! return the number of constants available in the ephemeris file */
    int calceph_getconstantcount(t_calcephbin* eph)
    
    #/*! return the name and the associated value of the constant available at some index in the ephemeris file */
    int calceph_getconstantindex(t_calcephbin* eph, int index, char name[33], double *value)
    
    #/*! return the id of the body using the given name in the ephemeris file */
    int calceph_getidbyname(t_calcephbin* eph, const char* name, int unit, int* id)
    
    #/*! return the first name of the body using the given identification number in the ephemeris file */
    int calceph_getnamebyidss(t_calcephbin* eph, int id, int unit, char name[1024])

    #/*! return the time scale in the ephemeris file */
    int calceph_gettimescale (t_calcephbin* eph)

    #/*! return the time span in the ephemeris file */
    int calceph_gettimespan (t_calcephbin* eph, double *firsttime, double *lasttime, int *continuous)

    #/*! return the number of position’s records available in the ephemeris file */
    int calceph_getpositionrecordcount(t_calcephbin* eph);

    #/*! return the target and origin bodies, the first and last time, and the reference frame available at the specified index for the position's records of the ephemeris file */
    int calceph_getpositionrecordindex(t_calcephbin* eph, int index, int* target, int* center, double* firsttime, double* lasttime, int* frame);

    #/*! return the target and origin bodies, the first and last time, the reference frame, and the segment type available at the specified index for the position's records of the ephemeris file */
    int calceph_getpositionrecordindex2(t_calcephbin* eph, int index, int* target, int* center, double* firsttime, double* lasttime, int* frame, int *segid);

    #/*! return the number of orientation’s records available in the ephemeris file */
    int calceph_getorientrecordcount(t_calcephbin* eph);

    #/*! return the target body, the first and last time, and the reference frame available at the specified index for the orientation's records of the ephemeris file */
    int calceph_getorientrecordindex(t_calcephbin* eph, int index, int* target,double* firsttime, double* lasttime, int* frame);

    #/*! return the target body, the first and last time, the reference frame, and the segment type at the specified index for the orientation's records of the ephemeris file */
    int calceph_getorientrecordindex2(t_calcephbin* eph, int index, int* target,double* firsttime, double* lasttime, int* frame, int *segid);

    #/*! return the version of the ephemeris file as a null-terminated string */
    void calceph_getfileversion(t_calcephbin* eph, char szversion[1024])

    #/*! close an ephemeris data file and destroy the ephemeris descriptor */
    void calceph_close(t_calcephbin* eph)
    
    #/*! return the maximal order of the derivatives for a segment type */
    int calceph_getmaxsupportedorder(int idseg)

    #/*! return the version of the library as a null-terminated string */
    void calceph_getversion_str(char szversion[33])


    #/*-----------------------------------------------------------------*/
    #/* instrument functions */
    #/*-----------------------------------------------------------------*/

    #/*! Return the field-of-view (FOV) parameters for a specified instrument */
    int calceph_getfov(t_calcephbin * eph, int instrumentid, int *shape, char frame[1024], double vector[3], double *arraybounds, int nbounds)

    #/*-----------------------------------------------------------------*/
    #/* time conversion */
    #/*-----------------------------------------------------------------*/

    #/*! convert the Julian day to the calendar date according to timescale */
    int calceph_time_jd_to_cal(t_calcephbin * eph, int timescale, double jd0, double jdfrac, int *yy, int *month, int *day, int *hh, int *min, double *sec)

    #/*! convert the calendar date to the Julian day according to timescale */
    int calceph_time_cal_to_jd(t_calcephbin * eph, int timescale, int yy, int month, int day, int hh, int min, double sec, double *jd0, double *jdfrac)

    #/*! parse the date, assumed in the timescale,  to the Julian day in the same timescale */
    int calceph_time_str_to_jd(t_calcephbin * eph, int timescale, const char *str, double *jd0, double *jdfrac)

    #/*! set the model used to convert the date between the timescales TT and TDB */
    int calceph_time_set_relationship_tt_tdb(t_calcephbin * eph, int model)

    #/*! convert the Julian day, expressed in the timescale TDB, the Julian day, expressed in the timescale TT */
    int calceph_time_jd_tdb_to_jd_tt(t_calcephbin * eph, double jd0_tdb, double jdfrac_tdb, double *jd0_tt, double *jdfrac_tt)

    #/*! convert the Julian day, expressed in the timescale TT, the Julian day, expressed in the timescale TDB */
    int calceph_time_jd_tt_to_jd_tdb(t_calcephbin * eph, double jd0_tt, double jdfrac_tt, double *jd0_tdb, double *jdfrac_tdb)

    #/*! convert the Julian day, expressed in the timescale TDB, the Julian day, expressed in the timescale TCB */
    int calceph_time_jd_tdb_to_jd_tcb(t_calcephbin * eph, double jd0_tdb, double jdfrac_tdb, double *jd0_tcb, double *jdfrac_tcb)

    #/*! convert the Julian day, expressed in the timescale TCB, the Julian day, expressed in the timescale TDB */
    int calceph_time_jd_tcb_to_jd_tdb(t_calcephbin * eph, double jd0_tcb, double jdfrac_tcb, double *jd0_tdb, double *jdfrac_tdb)


    #/*! parse the date to the Julian day expressed in the timescale TDB */
    int calceph_time_str_any_to_jd_tdb(t_calcephbin * eph, const char *str, double *jd0_tdb, double *jdfrac_tdb)

    #/*! parse the UTC date to the Julian day expressed in the timescale TDB */
    int calceph_time_str_utc_to_jd_tdb(t_calcephbin * eph, const char *str, double *jd0_tdb, double *jdfrac_tdb)

    #/*! convert the calendar date, expressed in the timescale UTC, to the Julian daye expressed in timescale TDB */
    int calceph_time_cal_utc_to_jd_tdb(t_calcephbin * eph, int yy, int month, int day, int hh, int min, double sec, double *jd0_tdb, double *jdfrac_tdb)

    #/*! convert the Julian day expressed in timescale TDB to the calendar date expressed in the timescale UTC */
    int calceph_time_jd_tdb_to_cal_utc(t_calcephbin * eph, double jd0_tdb, double jdfrac_tdb, int *yy, int *month, int *day, int *hh, int *min, double *sec)

    #/*! convert the space clock time string to the Julian day expressed in TDB */
    int calceph_time_str_spacecraft_clock_to_jd_tdb(t_calcephbin* eph, int target, const char* str, double* jd0_tdb, double* jdfrac_tdb);

    #/*! convert the Julian day expressed in TDB to space clock time string */
    int calceph_time_jd_tdb_to_str_spacecraft_clock(t_calcephbin* eph, int target, double jd0_tdb, double jdfrac_tdb,  char str[1024]);




# /*-----------------------------------------------------------------*/
# /*!
#  \file mgetnamebyidss.py
#  \brief Check if calceph_getnamebyidss works.
#
#  \author  M. Gastineau
#           Astronomie et Systemes Dynamiques, IMCCE, CNRS, Observatoire de Paris.
#
#   Copyright, 2024, CNRS
#   email of the author : Mickael.Gastineau@obspm.fr
# */
# /*-----------------------------------------------------------------*/
#
# /*-----------------------------------------------------------------*/
# /* License  of this file :
# This file is "triple-licensed", you have to choose one  of the three licenses
# below to apply on this file.
#
#    CeCILL-C
#    	The CeCILL-C license is close to the GNU LGPL.
#    	( http://www.cecill.info/licences/Licence_CeCILL-C_V1-en.html )
#
# or CeCILL-B
#        The CeCILL-B license is close to the BSD.
#        (http://www.cecill.info/licences/Licence_CeCILL-B_V1-en.txt)
#
# or CeCILL v2.1
#      The CeCILL license is compatible with the GNU GPL.
#      ( http://www.cecill.info/licences/Licence_CeCILL_V2.1-en.html )
#
#
# This library is governed by the CeCILL-C, CeCILL-B or the CeCILL license under
# French law and abiding by the rules of distribution of free software.
# You can  use, modify and/ or redistribute the software under the terms
# of the CeCILL-C,CeCILL-B or CeCILL license as circulated by CEA, CNRS and INRIA
# at the following URL "http://www.cecill.info".
#
# As a counterpart to the access to the source code and  rights to copy,
# modify and redistribute granted by the license, users are provided only
# with a limited warranty  and the software's author,  the holder of the
# economic rights,  and the successive licensors  have only  limited
# liability.
#
# In this respect, the user's attention is drawn to the risks associated
# with loading,  using,  modifying and/or developing or reproducing the
# software by the user in light of its specific status of free software,
# that may mean  that it is complicated to manipulate,  and  that  also
# therefore means  that it is reserved for developers  and  experienced
# professionals having in-depth computer knowledge. Users are therefore
# encouraged to load and test the software's suitability as regards their
# requirements in conditions enabling the security of their systems and/or
# data to be ensured and,  more generally, to use and operate it in the
# same conditions as regards security.
#
# The fact that you are presently reading this means that you have had
# knowledge of the CeCILL-C,CeCILL-B or CeCILL license and that you accept its terms.
# */
# /*-----------------------------------------------------------------*/

# /*-----------------------------------------------------------------*/
# /* main program */
# /*-----------------------------------------------------------------*/
import unittest
import openfiles

from calcephpy import CalcephBin, Constants


class TestOpen(unittest.TestCase):

    # /*-----------------------------------------------------------------*/
    # /* check the invalid id */
    # /*-----------------------------------------------------------------*/
    def check_failure(self, peph, id,  unit):
        name = peph.getnamebyidss(id, unit)
        if (name is None):
            ret = 0
        else:
            print("failure : find valid name but the id is invalid !!!\n")
            print("name=", name)
            print("unit=",  unit)
            print("id=",  id)
            ret = 1

        return ret


# /*-----------------------------------------------------------------*/
# /* check the valid id */
# /*-----------------------------------------------------------------*/
    def check_valid(self, peph, name_expected, unit, id):
        ret = 0
        try:
            name = peph.getnamebyidss(id, unit)
            if (name_expected != name):
                print("failure : find invalid name but the id is valid !!!\n")
                print("name_expected=", name_expected)
                print("name=", name)
                print("unit=",  unit)
                print("id=",  id)
                ret = 1
        except:
            ret = 1

        return ret


# /*-----------------------------------------------------------------*/
# /* main program */
# /*-----------------------------------------------------------------*/


    def test_getidbyname(self):
        peph = CalcephBin.open(openfiles.prefixsrc(
            "../../examples/example1.tpc"))
        res = 0

        res = res + self.check_failure(peph, -5000, 0)
        res = res + self.check_failure(peph, 998, 0)
        res = res + self.check_failure(peph, 21, 0)
        res = res + \
            self.check_failure(peph, -5000, Constants.USE_NAIFID)
        res = res + self.check_failure(peph, 998, Constants.USE_NAIFID)

        res = res + self.check_valid(peph, "JUPITER BARYCENTER", 0, 5)


        res = res + self.check_valid(peph, "SATURN BARYCENTER",
                                     Constants.USE_NAIFID, 6)

        res = res + self.check_valid(peph, "SATURN",
                                     Constants.USE_NAIFID, 699)

        res = res + self.check_valid(peph, "MERCURY BARYCENTER", 0, 1)
        res = res + self.check_valid(peph, "VENUS BARYCENTER", 0, 2)
        res = res + self.check_valid(peph, "EARTH", 0, 3)
        res = res + self.check_valid(peph, "MARS BARYCENTER", 0, 4)
        res = res + self.check_valid(peph, "SATURN BARYCENTER", 0, 6)
        res = res + self.check_valid(peph, "URANUS BARYCENTER", 0, 7)
        res = res + self.check_valid(peph, "NEPTUNE BARYCENTER", 0, 8)
        res = res + self.check_valid(peph, "PLUTO BARYCENTER", 0, 9)
        res = res + self.check_valid(peph, "MOON", 0, 10)
        res = res + self.check_valid(peph, "SUN", 0, 11)
        res = res + \
            self.check_valid(peph, "SOLAR SYSTEM BARYCENTER", 0, 12)
        res = res + self.check_valid(peph, "EARTH MOON BARYCENTER", 0, 13)

        res = res + self.check_valid(peph, "EARTH",
                                     Constants.USE_NAIFID, 399)
        res = res + self.check_valid(peph, "MOON", Constants.USE_NAIFID, 301)
        res = res + self.check_valid(peph, "SUN", Constants.USE_NAIFID, 10)
        res = res + \
            self.check_valid(peph, "SOLAR SYSTEM BARYCENTER",
                             Constants.USE_NAIFID, 0)
        res = res + \
            self.check_valid(peph, "EARTH MOON BARYCENTER",
                             Constants.USE_NAIFID, 3)

        res = res + self.check_valid(peph, "2 PALLAS",
                                     Constants.USE_NAIFID, 2000002)
        res = res + self.check_valid(peph, "1 CERES",
                                     Constants.USE_NAIFID, 2000001)

        if (res != 0):
            print("res=", res)
            raise RuntimeError("The test fail")

        peph.close()


if __name__ == '__main__':
    unittest.main()



#/*-----------------------------------------------------------------*/
#/*! 
#  \file mcheck.py
#  \brief Check the output of the function calceph_compute with an INPOP file.
#
#  \author  M. Gastineau 
#           Astronomie et Systemes Dynamiques, IMCCE, CNRS, Observatoire de Paris. 
#
#   Copyright, 2016, 2017, CNRS
#   email of the author : Mickael.Gastineau@obspm.fr
#*/
#/*-----------------------------------------------------------------*/
# 
#/*-----------------------------------------------------------------*/
#/* License  of this file :
# This file is "triple-licensed", you have to choose one  of the three licenses 
# below to apply on this file.
# 
#    CeCILL-C
#    	The CeCILL-C license is close to the GNU LGPL.
#    	( http://www.cecill.info/licences/Licence_CeCILL-C_V1-en.html )
#   
# or CeCILL-B
#        The CeCILL-B license is close to the BSD.
#        (http://www.cecill.info/licences/Licence_CeCILL-B_V1-en.txt)
#  
# or CeCILL v2.1
#      The CeCILL license is compatible with the GNU GPL.
#      ( http://www.cecill.info/licences/Licence_CeCILL_V2.1-en.html )
# 
#
# This library is governed by the CeCILL-C, CeCILL-B or the CeCILL license under 
# French law and abiding by the rules of distribution of free software.  
# You can  use, modify and/ or redistribute the software under the terms 
# of the CeCILL-C,CeCILL-B or CeCILL license as circulated by CEA, CNRS and INRIA  
# at the following URL "http://www.cecill.info". 
# 
# As a counterpart to the access to the source code and  rights to copy,
# modify and redistribute granted by the license, users are provided only
# with a limited warranty  and the software's author,  the holder of the
# economic rights,  and the successive licensors  have only  limited
# liability. 
# 
# In this respect, the user's attention is drawn to the risks associated
# with loading,  using,  modifying and/or developing or reproducing the
# software by the user in light of its specific status of free software,
# that may mean  that it is complicated to manipulate,  and  that  also
# therefore means  that it is reserved for developers  and  experienced
# professionals having in-depth computer knowledge. Users are therefore
# encouraged to load and test the software's suitability as regards their
# requirements in conditions enabling the security of their systems and/or 
# data to be ensured and,  more generally, to use and operate it in the 
# same conditions as regards security. 
# 
# The fact that you are presently reading this means that you have had
# knowledge of the CeCILL-C,CeCILL-B or CeCILL license and that you accept its terms.
# */
# /*-----------------------------------------------------------------*/

#/*-----------------------------------------------------------------*/
#/* main program */
#/*-----------------------------------------------------------------*/
import unittest
import openfiles
 
from calcephpy import CalcephBin
 
class TestOpen(unittest.TestCase):
 
    def mcheck_main(self, prefetch):
        peph = CalcephBin.open(openfiles.prefixsrc("../../examples/example1.dat"))
        if (prefetch==0):
            peph.prefetch()
        
        f = open(openfiles.prefixsrc('../../tests/example1_tests.dat'))
        d = f.readlines()
        datacheck = [x.split() for x in d]
        for aline in datacheck:
            jd0 = float(aline[0])
            target =  int(aline[1])
            center = int(aline[2])
            PVcheck = [0,0,0,0,0,0]
            for k in range(0,6):
                PVcheck[k] = float(aline[k+3])
            dt = jd0 - int(jd0)
            jd0 = (int(jd0)) + 2.4515450000000000000E+06
            PV = peph.compute(jd0, dt, target, center)
            seuil = 1E-8
            # /* for libration , return angles between 0 and 2*pi */
            if (target == 15):
                seuil = 1E-7;
                j = 2
                pi2 = 6.283185307179586E0
                while (PV[j] >= pi2):
                    PV[j] = PV[j] - pi2
                while (PV[j] <= 0) :
                   PV[j] = PV[j] + pi2;

            # /* check with references coordinates */
            n = 6
            for j in range(0,6):
                if (abs(PVcheck[j] - PV[j]) >= seuil):
                    print("failure for ",target, center, " at time ", jd0, dt)
                    print('aline=', aline)
                    for k in range(0,n):
                        print(k, "diff= ",target, center, " at time jd0, dt", PVcheck[k] - PV[k], PVcheck[k], PV[k])
                    print("prefetch=", prefetch)
                    raise RuntimeError("Internal failure")
           
        f.close()
        peph.close()
   
    def test_mcheck(self):
        self.mcheck_main(0)
        self.mcheck_main(1)
 
if __name__ == '__main__':
    unittest.main()



#/*-----------------------------------------------------------------*/
#/*! 
#  \file timespan.py
#  \brief Check if calceph_timespan works.
#
#  \author  M. Gastineau 
#           Astronomie et Systemes Dynamiques, IMCCE, CNRS, Observatoire de Paris. 
#
#   Copyright, 2017, CNRS
#   email of the author : Mickael.Gastineau@obspm.fr
#*/
#/*-----------------------------------------------------------------*/
# 
#/*-----------------------------------------------------------------*/
#/* License  of this file :
# This file is "triple-licensed", you have to choose one  of the three licenses 
# below to apply on this file.
# 
#    CeCILL-C
#    	The CeCILL-C license is close to the GNU LGPL.
#    	( http://www.cecill.info/licences/Licence_CeCILL-C_V1-en.html )
#   
# or CeCILL-B
#        The CeCILL-B license is close to the BSD.
#        (http://www.cecill.info/licences/Licence_CeCILL-B_V1-en.txt)
#  
# or CeCILL v2.1
#      The CeCILL license is compatible with the GNU GPL.
#      ( http://www.cecill.info/licences/Licence_CeCILL_V2.1-en.html )
# 
#
# This library is governed by the CeCILL-C, CeCILL-B or the CeCILL license under 
# French law and abiding by the rules of distribution of free software.  
# You can  use, modify and/ or redistribute the software under the terms 
# of the CeCILL-C,CeCILL-B or CeCILL license as circulated by CEA, CNRS and INRIA  
# at the following URL "http://www.cecill.info". 
# 
# As a counterpart to the access to the source code and  rights to copy,
# modify and redistribute granted by the license, users are provided only
# with a limited warranty  and the software's author,  the holder of the
# economic rights,  and the successive licensors  have only  limited
# liability. 
# 
# In this respect, the user's attention is drawn to the risks associated
# with loading,  using,  modifying and/or developing or reproducing the
# software by the user in light of its specific status of free software,
# that may mean  that it is complicated to manipulate,  and  that  also
# therefore means  that it is reserved for developers  and  experienced
# professionals having in-depth computer knowledge. Users are therefore
# encouraged to load and test the software's suitability as regards their
# requirements in conditions enabling the security of their systems and/or 
# data to be ensured and,  more generally, to use and operate it in the 
# same conditions as regards security. 
# 
# The fact that you are presently reading this means that you have had
# knowledge of the CeCILL-C,CeCILL-B or CeCILL license and that you accept its terms.
# */
# /*-----------------------------------------------------------------*/

#/*-----------------------------------------------------------------*/
#/* main program */
#/*-----------------------------------------------------------------*/
import unittest
import openfiles
 
from calcephpy import CalcephBin
 
class TestOpen(unittest.TestCase):
 
    def test_timespan(self):
        peph = CalcephBin.open(openfiles.prefixsrc("../../examples/example1.dat"))
        firsttime = 0
        lasttime  = 0
        continuous = 0
        (firsttime, lasttime, continuous) = peph.gettimespan()
            
        firsttime_expected = 2442457.0E0
        lasttime_expected  = 2451545.0E0
        continuous_expected = 1
        if (continuous!=1) :
            print("continuous=", continuous)
            raise RuntimeError("The test fail")
        if (abs(firsttime-firsttime_expected)>1E-13) :
            print("firsttime computed=", firsttime)
            print("firsttime expected=", firsttime_expected)
            raise RuntimeError("The test fail")
        if (abs(lasttime-lasttime_expected)>1E-13) :
            print("lasttime computed=", lasttime)
            print("lasttime expected=", lasttime_expected)
            raise RuntimeError("The test fail")
        peph.close()
 
if __name__ == '__main__':
    unittest.main()
